==> aws-cdk-ssm-sdk-parameter-0.0.8.tar.gz: package/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### 0.0.8 (2020-12-29)

### 0.0.7 (2020-12-26)


### Features

* cleanup ([60c7c04](https://github.com/mmuller88/aws-cdk-ssm-sdk-parameter/commit/60c7c04c7da47311a6ac1b8133c3dcb56f1e68ef))

### 0.0.6 (2020-12-26)


### Features

* adjust ignores ([58071f9](https://github.com/mmuller88/aws-cdk-ssm-sdk-parameter/commit/58071f9a758e40cc090b2dea2054aa3aa6af9760))

### 0.0.5 (2020-12-26)

### 0.0.4 (2020-12-26)


### Features

* release to npm and pypi ([c296fbb](https://github.com/mmuller88/aws-cdk-ssm-sdk-parameter/commit/c296fbb3ec8f62795f34d5471662a45dc27427f0))

### 0.0.3 (2020-12-26)


### Features

* release to npm and pypi ([7201153](https://github.com/mmuller88/aws-cdk-ssm-parameter/commit/7201153616fb946c620ec7fe812e004941f4ee08))

### 0.0.2 (2020-12-26)


### Features

* release to npm and pypi ([e84576b](https://github.com/mmuller88/aws-cdk-ssm-parameter/commit/e84576b4c8b61e765f5e6f9f4006e620907b11e0))

### 0.0.1 (2020-12-26)


### Features

* add more unit tests + policy finetuning ([da1d5da](https://github.com/mmuller88/aws-cdk-ssm-parameter/commit/da1d5dac7a1a944a031e787cc9d304e1bae7d7e9))
* add optional delete property ([9210829](https://github.com/mmuller88/aws-cdk-ssm-parameter/commit/92108298d47a89f52390e1afd11e22eb699533fd))
* bump projen ([faaa4d5](https://github.com/mmuller88/aws-cdk-ssm-parameter/commit/faaa4d5c4c0245170036c1ebd1103e96e3674453))
* init ([69524e2](https://github.com/mmuller88/aws-cdk-ssm-parameter/commit/69524e2529c26f8a407a504f7efff6a4cc1425cc))
* init ([2f7ca2c](https://github.com/mmuller88/aws-cdk-ssm-parameter/commit/2f7ca2c90fea567d600f6c470d9ec24165e2d0f2))
* init unit tests ([05b2a45](https://github.com/mmuller88/aws-cdk-ssm-parameter/commit/05b2a45bcde89ea53d50fac2868e1d64e8bd2b44))
* init unit tests ([55a8b40](https://github.com/mmuller88/aws-cdk-ssm-parameter/commit/55a8b40a6953648789885fa50ce869d6f6be2cae))
* SSMParameter ([d6aa2db](https://github.com/mmuller88/aws-cdk-ssm-parameter/commit/d6aa2db38f1308a9064c5e7e831f2f82737132d5))
* SSMParameter created ([741f82a](https://github.com/mmuller88/aws-cdk-ssm-parameter/commit/741f82a6d22a7c06b7098c614cc52b266043ac25))
* SSMParameter created ([7f90145](https://github.com/mmuller88/aws-cdk-ssm-parameter/commit/7f901455504798b3ed05432556fd1ccfa833c0e6))
* use AWSCustomResource ([330204b](https://github.com/mmuller88/aws-cdk-ssm-parameter/commit/330204bb374aec7d96191874bd4028598391eaf7))
* use AWSCustomResource ([66f9555](https://github.com/mmuller88/aws-cdk-ssm-parameter/commit/66f9555f683ea63112637c431bc2f82d56e8825e))

==> aws-cdk-ssm-sdk-parameter-0.0.9.tar.gz: package/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### [0.0.9](https://github.com/mmuller88/aws-cdk-ssm-sdk-parameter/compare/v0.0.8...v0.0.9) (2021-04-05)

### 0.0.8 (2020-12-29)

### 0.0.7 (2020-12-26)


### Features

* cleanup ([60c7c04](https://github.com/mmuller88/aws-cdk-ssm-sdk-parameter/commit/60c7c04c7da47311a6ac1b8133c3dcb56f1e68ef))

### 0.0.6 (2020-12-26)


### Features

* adjust ignores ([58071f9](https://github.com/mmuller88/aws-cdk-ssm-sdk-parameter/commit/58071f9a758e40cc090b2dea2054aa3aa6af9760))

### 0.0.5 (2020-12-26)

### 0.0.4 (2020-12-26)


### Features

* release to npm and pypi ([c296fbb](https://github.com/mmuller88/aws-cdk-ssm-sdk-parameter/commit/c296fbb3ec8f62795f34d5471662a45dc27427f0))

### 0.0.3 (2020-12-26)


### Features

* release to npm and pypi ([7201153](https://github.com/mmuller88/aws-cdk-ssm-parameter/commit/7201153616fb946c620ec7fe812e004941f4ee08))

### 0.0.2 (2020-12-26)


### Features

* release to npm and pypi ([e84576b](https://github.com/mmuller88/aws-cdk-ssm-parameter/commit/e84576b4c8b61e765f5e6f9f4006e620907b11e0))

### 0.0.1 (2020-12-26)


### Features

* add more unit tests + policy finetuning ([da1d5da](https://github.com/mmuller88/aws-cdk-ssm-parameter/commit/da1d5dac7a1a944a031e787cc9d304e1bae7d7e9))
* add optional delete property ([9210829](https://github.com/mmuller88/aws-cdk-ssm-parameter/commit/92108298d47a89f52390e1afd11e22eb699533fd))
* bump projen ([faaa4d5](https://github.com/mmuller88/aws-cdk-ssm-parameter/commit/faaa4d5c4c0245170036c1ebd1103e96e3674453))
* init ([69524e2](https://github.com/mmuller88/aws-cdk-ssm-parameter/commit/69524e2529c26f8a407a504f7efff6a4cc1425cc))
* init ([2f7ca2c](https://github.com/mmuller88/aws-cdk-ssm-parameter/commit/2f7ca2c90fea567d600f6c470d9ec24165e2d0f2))
* init unit tests ([05b2a45](https://github.com/mmuller88/aws-cdk-ssm-parameter/commit/05b2a45bcde89ea53d50fac2868e1d64e8bd2b44))
* init unit tests ([55a8b40](https://github.com/mmuller88/aws-cdk-ssm-parameter/commit/55a8b40a6953648789885fa50ce869d6f6be2cae))
* SSMParameter ([d6aa2db](https://github.com/mmuller88/aws-cdk-ssm-parameter/commit/d6aa2db38f1308a9064c5e7e831f2f82737132d5))
* SSMParameter created ([741f82a](https://github.com/mmuller88/aws-cdk-ssm-parameter/commit/741f82a6d22a7c06b7098c614cc52b266043ac25))
* SSMParameter created ([7f90145](https://github.com/mmuller88/aws-cdk-ssm-parameter/commit/7f901455504798b3ed05432556fd1ccfa833c0e6))
* use AWSCustomResource ([330204b](https://github.com/mmuller88/aws-cdk-ssm-parameter/commit/330204bb374aec7d96191874bd4028598391eaf7))
* use AWSCustomResource ([66f9555](https://github.com/mmuller88/aws-cdk-ssm-parameter/commit/66f9555f683ea63112637c431bc2f82d56e8825e))
